You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beehive.apache.org by ek...@apache.org on 2005/05/13 16:12:45 UTC

svn commit: r170020 - in /incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui: databinding/datagrid/api/filter/Filter.java databinding/datagrid/api/filter/FilterOperationHint.java databinding/datagrid/api/sort/SortModel.java tags/databinding/datagrid/AbstractHtmlTableCell.java tags/databinding/invoke/CallMethod.java

Author: ekoneil
Date: Fri May 13 07:12:44 2005
New Revision: 170020

URL: http://svn.apache.org/viewcvs?rev=170020&view=rev
Log:
Javadoc checkpoint.

BB: self
DRT: Beehive pass / build.dist pass


Modified:
    incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/filter/Filter.java
    incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/filter/FilterOperationHint.java
    incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/sort/SortModel.java
    incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/tags/databinding/datagrid/AbstractHtmlTableCell.java
    incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/tags/databinding/invoke/CallMethod.java

Modified: incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/filter/Filter.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/filter/Filter.java?rev=170020&r1=170019&r2=170020&view=diff
==============================================================================
--- incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/filter/Filter.java (original)
+++ incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/filter/Filter.java Fri May 13 07:12:44 2005
@@ -22,21 +22,33 @@
 /**
 * <p>
 * The Filter class is a JavaBean that abstractly represents the data needed to calculate a filter
-* for some data set.  A filter consists of some {@link String} expression, a {@link FilterOperation}
+* for a data set.  A filter consists of some {@link String} expression, a {@link FilterOperation}
 * and a filter value.  The mechanism for applying a filter to a data set is not provided here.
 * </p>
 * <p>
-* A filter object can be used by some filtering infrastructure to either parameterize a SQL or XQuery
-* query or to simply sort an in-memory data set.  For example,
-
-* query or to simply sort in-memory Java objects.   For example, when converting a Sort into
-* a SQL fragment, a Sort with sortExpression "foo" and sortDirection {@link org.apache.beehive.netui.databinding.datagrid.api.sort.SortDirection.DESCENDING} could
-* be converted into:
-* <pre>
-*     ORDER BY FOO DESC
-* </pre>
-* </p>
-*/
+ * The filter expression is used to abstractly name some part of a data set to filter.  The filter operation
+ * is used to describe the operation to use when performing filtering.  The set of operations for
+ * available for use should be related to a subclass of the Filter type; there are no implicitly
+ * defined operations.  The filter value is used to describe how to filter a given filter expression.
+ * For example, in an application performing filtering using SQL, a filter expression <code>pet</code>
+ * with a filter operation mapping to "equals" and a filter value of "dog" could be transformed
+ * into a SQL WHERE fragment as:
+ * <pre>
+ *   WHERE pet = 'dog'
+ * </pre>
+ * The Filter class simply provides an abstraction for a filter's metadata; the mechanism for performing
+ * this transformation from Filter instance to SQL fragment is not provided here.
+ * </p>
+ * <p>
+ * In addition to the fundamental data fora Filter, two additional properties can be defined.  The
+ * {@link org.apache.beehive.netui.databinding.datagrid.api.filter.FilterOperationHint} property can
+ * be used to reference a class of operation related to the hint.  The
+ * {@link org.apache.beehive.netui.databinding.datagrid.api.filter.FilterTypeHint} property
+ * defines a hint for the type of data associated with the Filter's filter expression.  This data can be
+ * used to handle quoting and type conversion for a given filter value.  In the example above, a type hint of
+ * a {@link org.apache.beehive.netui.databinding.datagrid.api.filter.FilterTypeHint#STRING} can be used
+ * when constructing the SQL fragment in order to perform the correct quoting of the filter value.
+ */
 public class Filter
     implements java.io.Serializable {
 
@@ -49,38 +61,75 @@
 
     private FilterTypeHint _typeHint = FilterTypeHint.getDefault();
 
+    /**
+     * Get the type hint for this filter.
+     * @return the filter type hint
+     */
     public FilterTypeHint getTypeHint() {
         return _typeHint;
     }
 
+    /**
+     * Set the type hint for this filter
+     * @param typeHint the filter type hint
+     */
     public void setTypeHint(FilterTypeHint typeHint) {
         _typeHint = typeHint;
     }
 
+    /**
+     * Set the filter expression for this filter
+     * @param filterExpression the filter expression
+     */
     public void setFilterExpression(String filterExpression) {
         _filterExpression = filterExpression;
     }
 
+    /**
+     * Get the filter expression for this filter
+     * @return the filter expression
+     */
     public String getFilterExpression() {
         return _filterExpression;
     }
 
+    /**
+     * Set the filter operation for this filter
+     * @param filterOperation the filter operation
+     */
     public void setOperation(FilterOperation filterOperation) {
         _filterOperation = filterOperation;
     }
 
+    /**
+     * Get the filter operation for this filter
+     * @return the filter operation
+     */
     public FilterOperation getOperation() {
         return _filterOperation;
     }
 
+    /**
+     * Get the operation hint for this filter
+     * @return the filter operation hint
+     */
     public FilterOperationHint getOperationHint() {
         return _filterOperationHint;
     }
 
+    /**
+     * Set the operation hint for this filter
+     * @param filterOperationHint the filter operation hint
+     */
     public void setOperationHint(FilterOperationHint filterOperationHint) {
         _filterOperationHint = filterOperationHint;
     }
 
+    /**
+     * Set the value for this filter.  Note, in the default implementation, the <code>value</code>
+     * must implement {@link java.io.Serializable}.
+     * @param value the value
+     */
     public void setValue(Object value) {
 
         if(LOGGER.isInfoEnabled() && !(value instanceof java.io.Serializable))
@@ -89,6 +138,10 @@
         _value = value;
     }
 
+    /**
+     * Get the value for this filter.
+     * @return the value
+     */
     public Object getValue() {
         return _value;
     }

Modified: incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/filter/FilterOperationHint.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/filter/FilterOperationHint.java?rev=170020&r1=170019&r2=170020&view=diff
==============================================================================
--- incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/filter/FilterOperationHint.java (original)
+++ incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/filter/FilterOperationHint.java Fri May 13 07:12:44 2005
@@ -18,43 +18,162 @@
 package org.apache.beehive.netui.databinding.datagrid.api.filter;
 
 /**
- *
+ * <p>
+ * This class provides a hint for the operation performed by a
+ * {@link org.apache.beehive.netui.databinding.datagrid.api.filter.Filter} instance.  The
+ * filter operations supported for a specific query language are not encoded in the
+ * FilterOperation class and are provided on an per-instance basis.  The hint provides
+ * a way of representing a generic type of operation.  The operations here are common
+ * across query languages and are not meant to be an exhaustive list.
+ * </p>
+ * <p>
+ * Setting a FilterOperationHint on a Filter object, allows query infrastructure to
+ * generically interact with Filter instances regardless of the type of query mechanism.
+ * </p>
  */
 public class FilterOperationHint
     implements java.io.Serializable {
 
+    /**
+     * Int value representing no operation.
+     */
     public static final int INT_NONE = 0;
+
+    /**
+     * Int value representing equal.
+     */
     public static final int INT_EQUAL = 1;
+
+    /**
+     * Int value representing not equal.
+     */
     public static final int INT_NOT_EQUAL = 2;
+
+    /**
+     * Int value representing greater than.
+     */
     public static final int INT_GREATER_THAN = 3;
+
+    /**
+     * Int value representing less than.
+     */
     public static final int INT_LESS_THAN = 4;
+
+    /**
+     * Int value representing greater than or equal.
+     */
     public static final int INT_GREATER_THAN_OR_EQUAL = 5;
+
+    /**
+     * Int value representing less than or equal.
+     */
     public static final int INT_LESS_THAN_OR_EQUAL = 6;
+
+    /**
+     * Int value representing is one of.
+     */
     public static final int INT_IS_ONE_OF = 7;
+
+    /**
+     * Int value representing starts with.
+     */
     public static final int INT_STARTS_WITH = 8;
+
+    /**
+     * Int value representing contains.
+     */
     public static final int INT_CONTAINS = 9;
+
+    /**
+     * Int value representing is empty.
+     */
     public static final int INT_IS_EMPTY = 10;
+
+    /**
+     * Int value representing is not empty.
+     */
     public static final int INT_IS_NOT_EMPTY = 11;
 
+    /**
+     * Operation representing no filter.
+     */
     public static final FilterOperationHint NONE = new FilterOperationHint(INT_NONE);
+
+    /**
+     * Operation representing equal.
+     */
     public static final FilterOperationHint EQUAL = new FilterOperationHint(INT_EQUAL);
+
+    /**
+     * Operation representing not equal.
+     */
     public static final FilterOperationHint NOT_EQUAL = new FilterOperationHint(INT_NOT_EQUAL);
+
+    /**
+     * Operation representing greater than.
+     */
     public static final FilterOperationHint GREATER_THAN = new FilterOperationHint(INT_GREATER_THAN);
+
+    /**
+     * Operation representing less than.
+     */
     public static final FilterOperationHint LESS_THAN = new FilterOperationHint(INT_LESS_THAN);
+
+    /**
+     * Operation representing greater than or equal.
+     */
     public static final FilterOperationHint GREATER_THAN_OR_EQUAL = new FilterOperationHint(INT_GREATER_THAN_OR_EQUAL);
+
+    /**
+     * Operation representing less than or equal.
+     */
     public static final FilterOperationHint LESS_THAN_OR_EQUAL = new FilterOperationHint(INT_LESS_THAN_OR_EQUAL);
+
+    /**
+     * Operation representing is one of.  The implementations of an 'is one of' operation is left
+     * to the interpreter of a Filter instance.
+     */
     public static final FilterOperationHint IS_ONE_OF = new FilterOperationHint(INT_IS_ONE_OF);
+
+    /**
+     * Operation representing starts with.
+     */
     public static final FilterOperationHint STARTS_WITH = new FilterOperationHint(INT_STARTS_WITH);
+
+    /**
+     * Operation representing 'contains'.  The implementation of a contains operation is left
+     * to the interpreter of a Filter instance.
+     */
     public static final FilterOperationHint CONTAINS = new FilterOperationHint(INT_CONTAINS);
+
+    /**
+     * Operation representing 'is empty'.
+     */
     public static final FilterOperationHint IS_EMPTY = new FilterOperationHint(INT_IS_EMPTY);
+
+    /**
+     * Operation representing 'is not empty'.
+     */
     public static final FilterOperationHint IS_NOT_EMPTY = new FilterOperationHint(INT_IS_NOT_EMPTY);
 
+    /**
+     * Integer representation of the filter operation.
+     */
     private int _val;
 
+    /**
+     * Private constructor.
+     * @param val the filter value
+     */
     private FilterOperationHint(int val) {
         _val = val;
     }
 
+    /**
+     * Convert this filter operation hint to a readable String.  Note, this does not return the
+     * operator -- only text for the operation hint itself.
+     * @return the readable operation name
+     */
     public final String toString() {
         switch(_val) {
             case INT_NONE:
@@ -89,6 +208,11 @@
         throw new IllegalStateException(message);
     }
 
+    /**
+     * Equals method.
+     * @param value value to check
+     * @return <code>true</code> if this hint matches the <code>value</code>.  <code>false</code> otherwise.
+     */
     public boolean equals(Object value) {
         if(value == this)
             return true;
@@ -99,10 +223,19 @@
         return ((FilterOperationHint)value)._val == _val;
     }
 
+    /**
+     * Hash code.
+     * @return the hash code
+     */
     public int hashCode() {
         return _val;
     }
 
+    /**
+     * The hint's int value.
+     *
+     * @return the hint's value
+     */
     public int getValue() {
         return _val;
     }

Modified: incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/sort/SortModel.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/sort/SortModel.java?rev=170020&r1=170019&r2=170020&view=diff
==============================================================================
--- incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/tags/databinding/datagrid/AbstractHtmlTableCell.java (original)
+++ incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/tags/databinding/datagrid/AbstractHtmlTableCell.java Fri May 13 07:12:44 2005
@@ -53,7 +53,6 @@
      * @param sortExpression
      * @netui:attribute required="false" rtexprvalue="true"
      * @jsptagref.attributedescription [todo]
-     * @jsptagref.databindable true
      * @jsptagref.attributesyntaxvalue <i>string</i>
      */
     public void setSortExpression(String sortExpression) {
@@ -64,7 +63,6 @@
      * @param filterExpression
      * @netui:attribute required="false" rtexprvalue="true"
      * @jsptagref.attributedescription [todo]
-     * @jsptagref.databindable true
      * @jsptagref.attributesyntaxvalue <i>string</i>
      */
     public void setFilterExpression(String filterExpression) {
@@ -83,7 +81,6 @@
      *
      * @param onClick - the onClick event.
      * @jsptagref.attributedescription The onClick JavaScript event.
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_onClick</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The onClick JavaScript event."
      */
@@ -96,7 +93,6 @@
      *
      * @param onDblClick - the onDblClick event.
      * @jsptagref.attributedescription The onDblClick JavaScript event.
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_onDblClick</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The onDblClick JavaScript event."
      */
@@ -109,7 +105,6 @@
      *
      * @param onKeyDown - the onKeyDown event.
      * @jsptagref.attributedescription The onKeyDown JavaScript event.
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_onKeyDown</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The onKeyDown JavaScript event."
      */
@@ -122,7 +117,6 @@
      *
      * @param onKeyUp - the onKeyUp event.
      * @jsptagref.attributedescription The onKeyUp JavaScript event.
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_onKeyUp</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The onKeyUp JavaScript event."
      */
@@ -135,7 +129,6 @@
      *
      * @param onKeyPress - the onKeyPress event.
      * @jsptagref.attributedescription The onKeyPress JavaScript event.
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_onKeyPress</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The onKeyPress JavaScript event."
      */
@@ -148,7 +141,6 @@
      *
      * @param onMouseDown - the onMouseDown event.
      * @jsptagref.attributedescription The onMouseDown JavaScript event.
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_onMouseDown</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The onMouseDown JavaScript event."
      */
@@ -161,7 +153,6 @@
      *
      * @param onMouseUp - the onMouseUp event.
      * @jsptagref.attributedescription The onMouseUp JavaScript event.
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_onMouseUp</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The onMouseUp JavaScript event."
      */
@@ -174,7 +165,6 @@
      *
      * @param onMouseMove - the onMouseMove event.
      * @jsptagref.attributedescription The onMouseMove JavaScript event.
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_onMouseMove</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The onMouseMove JavaScript event."
      */
@@ -187,7 +177,6 @@
      *
      * @param onMouseOut - the onMouseOut event.
      * @jsptagref.attributedescription The onMouseOut JavaScript event.
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_onMouseOut</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The onMouseOut JavaScript event."
      */
@@ -200,7 +189,6 @@
      *
      * @param onMouseOver - the onMouseOver event.
      * @jsptagref.attributedescription The onMouseOver JavaScript event.
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_onMouseOver</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The onMouseOver JavaScript event."
      */
@@ -213,7 +201,6 @@
      *
      * @param style - the html style.
      * @jsptagref.attributedescription The style.
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_style</i>
      * @netui:attribute required="false"  rtexprvalue="true" description="The style."
      */
@@ -228,7 +215,6 @@
      *
      * @param styleClass - the html style class.
      * @jsptagref.attributedescription The style class.
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_style_class</i>
      * @netui:attribute required="false"  rtexprvalue="true" description="The style class."
      */
@@ -243,7 +229,6 @@
      *
      * @param title
      * @jsptagref.attributedescription The title.
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_title</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The title. "
      */
@@ -256,7 +241,6 @@
      *
      * @param rowSpan
      * @jsptagref.attributedescription The row span
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_rowspan</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The rowspan."
      */
@@ -269,7 +253,6 @@
      *
      * @param colSpan
      * @jsptagref.attributedescription The colspan
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_colspan</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The colspan."
      */
@@ -282,7 +265,6 @@
      *
      * @param align
      * @jsptagref.attributedescription The horizontal alignment.
-     * @jsptagref.databindable true
      * @jsptagref.attributesyntaxvalue <i>string_align</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The cell's horizontal alignment"
      */
@@ -296,7 +278,6 @@
      *
      * @param alignChar
      * @jsptagref.attributedescription The horizontal alignment character.
-     * @jsptagref.databindable true
      * @jsptagref.attributesyntaxvalue <i>string_alignChar</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The cell's horizontal alignment character"
      */
@@ -309,7 +290,6 @@
      *
      * @param alignCharOff
      * @jsptagref.attributedescription The horizontal alignment character offset
-     * @jsptagref.databindable true
      * @jsptagref.attributesyntaxvalue <i>string_alignCharOff</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The cell's horizontal alignment character offset"
      */
@@ -322,7 +302,6 @@
      *
      * @param align
      * @jsptagref.attributedescription The vertical alignment.
-     * @jsptagref.databindable true
      * @jsptagref.attributesyntaxvalue <i>string_align</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The cell's vertical alignment"
      */
@@ -336,7 +315,6 @@
      *
      * @param lang
      * @jsptagref.attributedescription The language.
-     * @jsptagref.databindable true
      * @jsptagref.attributesyntaxvalue <i>string_lang</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The cell's language"
      */
@@ -349,7 +327,6 @@
      *
      * @param dir
      * @jsptagref.attributedescription The text direction attribute.
-     * @jsptagref.databindable true
      * @jsptagref.attributesyntaxvalue <i>string_dir</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The cell's text direction"
      */
@@ -362,7 +339,6 @@
      *
      * @param abbr
      * @jsptagref.attributedescription The abbreviated form of the cell's content.
-     * @jsptagref.databindable true
      * @jsptagref.attributesyntaxvalue <i>string_dir</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The abbreviated form of the cell's content"
      */
@@ -375,7 +351,6 @@
      *
      * @param axis
      * @jsptagref.attributedescription The axis attribute.
-     * @jsptagref.databindable true
      * @jsptagref.attributesyntaxvalue <i>string_axis</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The axis attribute"
      */
@@ -388,7 +363,6 @@
      *
      * @param headers
      * @jsptagref.attributedescription The headers attribute.
-     * @jsptagref.databindable true
      * @jsptagref.attributesyntaxvalue <i>string_headers</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The headers attribute"
      */
@@ -401,7 +375,6 @@
      *
      * @param scope
      * @jsptagref.attributedescription The scope attribute.
-     * @jsptagref.databindable true
      * @jsptagref.attributesyntaxvalue <i>string_scope</i>
      * @netui:attribute required="false" rtexprvalue="true" description="The scope attribute"
      */
@@ -414,7 +387,6 @@
      *
      * @param tagId - the the name of the tagId for the td.
      * @jsptagref.attributedescription The tagId.
-     * @jsptagref.databindable false
      * @jsptagref.attributesyntaxvalue <i>string_tagId</i>
      * @netui:attribute required="false" rtexprvalue="true"
      * description="String value. Sets the id (or name) attribute of the rendered HTML tag. "

Modified: incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/tags/databinding/invoke/CallMethod.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/tags/databinding/invoke/CallMethod.java?rev=170020&r1=170019&r2=170020&view=diff
==============================================================================
--- incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/tags/databinding/invoke/CallMethod.java (original)
+++ incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/tags/databinding/invoke/CallMethod.java Fri May 13 07:12:44 2005
@@ -19,7 +19,6 @@
 
 import org.apache.beehive.netui.util.Bundle;
 import org.apache.beehive.netui.util.internal.cache.MethodCache;
-import org.apache.beehive.netui.util.logging.Logger;
 
 import javax.servlet.jsp.JspException;
 import java.lang.reflect.Method;
@@ -77,7 +76,7 @@
  * @see javax.servlet.jsp.PageContext
  */
 public class CallMethod
-        extends AbstractCallMethod {
+    extends AbstractCallMethod {
 
     private static final String DEFAULT_OBJECT_NAME = Bundle.getString("Tags_CallMethod_defaultObjectName");
     private static final MethodCache _cache = new MethodCache();
--- incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/sort/SortModel.java (original)
+++ incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/databinding/datagrid/api/sort/SortModel.java Fri May 13 07:12:44 2005
@@ -18,6 +18,7 @@
 package org.apache.beehive.netui.databinding.datagrid.api.sort;
 
 import java.util.List;
+import org.apache.beehive.netui.databinding.datagrid.api.sort.SortDirection;
 
 /**
  * <p>
@@ -35,7 +36,8 @@
  * In addition to accessing the Sort objects, the SortModel provides a the ability to plug a simple state
  * machine that controls how to change a sort direction when cycling through the set of sort directions.
  * For example, when using a data grid to sort columns of data, a column may start off unsorted,
  * change to {@link SortDirection.ASCENDING}, to {@link SortDirection.DESCENDING}, and finally back to
  * {@link SortDirection.NONE}.  The {@link SortStrategy} allows this strategy to be changed so that the
  * sorts can change from {@link SortDirection.NONE} to {@link SortDirection.DESCENDING}, to
  * {@link SortDirection.ASCENDING}, and finally back to {@link SortDirection.NONE}.
@@ -35,7 +36,8 @@
  * machine that controls how to change a sort direction when cycling through the set of sort directions.
  * For example, when using a data grid to sort columns of data, a column may start off unsorted,
- * change to {@link SortDirection.ASCENDING}, to {@link SortDirection.DESCENDING}, and finally back to
+ * change to {@link org.apache.beehive.netui.databinding.datagrid.api.sort.SortDirection.ASCENDING}, to
+ * {@link org.apache.beehive.netui.databinding.datagrid.api.sort.SortDirection.DESCENDING}, and finally back to
  * {@link SortDirection.NONE}.  The {@link SortStrategy} allows this strategy to be changed so that the
  * sorts can change from {@link SortDirection.NONE} to {@link SortDirection.DESCENDING}, to

Modified: incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/tags/databinding/datagrid/AbstractHtmlTableCell.java
URL: http://svn.apache.org/viewcvs/incubator/beehive/trunk/netui/src/tags-databinding/org/apache/beehive/netui/tags/databinding/datagrid/AbstractHtmlTableCell.java?rev=170020&r1=170019&r2=170020&view=diff
==============================================================================